==> jc-1.4.0.tar.gz: javax/print/event/PrintJobAttributeEvent.h <==
// public class javax.print.event.PrintJobAttributeEvent

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 4c95768fb6372ef3 javax_print_event_PrintEvent
// @dep_class a903e261b783b714 javax_print_event_PrintJobAttributeEvent

// header file dependencies
// @dep_header javax_print_event_PrintEvent

#include "javax/print/event/PrintEvent.h"

#ifndef _JC_javax_print_event_PrintJobAttributeEvent_H_
#define _JC_javax_print_event_PrintJobAttributeEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_print_DocPrintJob$object;
struct _jc_javax_print_attribute_PrintJobAttributeSet$object;

// Typedefs
typedef struct _jc_javax_print_event_PrintJobAttributeEvent$sub_refs	_jc_javax_print_event_PrintJobAttributeEvent$sub_refs;
typedef struct _jc_javax_print_event_PrintJobAttributeEvent$sub_nonrefs	_jc_javax_print_event_PrintJobAttributeEvent$sub_nonrefs;
typedef struct _jc_javax_print_event_PrintJobAttributeEvent$refs	_jc_javax_print_event_PrintJobAttributeEvent$refs;
typedef struct _jc_javax_print_event_PrintJobAttributeEvent$nonrefs	_jc_javax_print_event_PrintJobAttributeEvent$nonrefs;
typedef struct _jc_javax_print_event_PrintJobAttributeEvent$object	_jc_javax_print_event_PrintJobAttributeEvent$object;

typedef struct _jc_javax_print_event_PrintJobAttributeEvent$fields_struct	_jc_javax_print_event_PrintJobAttributeEvent$fields_struct;
typedef const struct _jc_javax_print_event_PrintJobAttributeEvent$vmethods	_jc_javax_print_event_PrintJobAttributeEvent$vmethods;
typedef const struct _jc_javax_print_event_PrintJobAttributeEvent$vtable	_jc_javax_print_event_PrintJobAttributeEvent$vtable;
typedef const struct _jc_javax_print_event_PrintJobAttributeEvent$vtype	_jc_javax_print_event_PrintJobAttributeEvent$vtype;

// Class fields structure
struct _jc_javax_print_event_PrintJobAttributeEvent$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_print_event_PrintJobAttributeEvent$fields_struct _jc_javax_print_event_PrintJobAttributeEvent$class_fields;

// Constructors
extern void _jc_javax_print_event_PrintJobAttributeEvent$method$_init$250893578e891781(_jc_env *, struct _jc_javax_print_event_PrintJobAttributeEvent$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_javax_print_event_PrintJobAttributeEvent$method$getAttributes$c572024cf02dfe99(_jc_env *, struct _jc_javax_print_event_PrintJobAttributeEvent$object *);
extern struct _jc_object *_jc_javax_print_event_PrintJobAttributeEvent$method$getPrintJob$f4a934baad9b84c8(_jc_env *, struct _jc_javax_print_event_PrintJobAttributeEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_event_PrintJobAttributeEvent$method_info$getAttributes$c572024cf02dfe99;
extern _jc_method _jc_javax_print_event_PrintJobAttributeEvent$method_info$getPrintJob$f4a934baad9b84c8;

// Virtual methods structure
struct _jc_javax_print_event_PrintJobAttributeEvent$vmethods {
	struct _jc_object	*(*getAttributes$c572024cf02dfe99)(_jc_env *, struct _jc_javax_print_event_PrintJobAttributeEvent$object *);
	struct _jc_object	*(*getPrintJob$f4a934baad9b84c8)(_jc_env *, struct _jc_javax_print_event_PrintJobAttributeEvent$object *);
};

// Vtable
struct _jc_javax_print_event_PrintJobAttributeEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_print_event_PrintEvent$vmethods	javax_print_event_PrintEvent;
	_jc_javax_print_event_PrintJobAttributeEvent$vmethods	javax_print_event_PrintJobAttributeEvent;
};

// Vtype
struct _jc_javax_print_event_PrintJobAttributeEvent$vtype {
	_jc_type			type;
	_jc_javax_print_event_PrintJobAttributeEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_event_PrintJobAttributeEvent$sub_refs {
	struct _jc_object	*attributes;
};

// Reference instance fields (object)
struct _jc_javax_print_event_PrintJobAttributeEvent$refs {
    _jc_javax_print_event_PrintJobAttributeEvent$sub_refs	javax_print_event_PrintJobAttributeEvent;
    _jc_javax_print_event_PrintEvent$sub_refs	javax_print_event_PrintEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_event_PrintJobAttributeEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_event_PrintJobAttributeEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_print_event_PrintEvent$sub_nonrefs	javax_print_event_PrintEvent;
    _jc_javax_print_event_PrintJobAttributeEvent$sub_nonrefs	javax_print_event_PrintJobAttributeEvent;
};

// Object instance structure
struct _jc_javax_print_event_PrintJobAttributeEvent$object {
	_jc_javax_print_event_PrintJobAttributeEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_event_PrintJobAttributeEvent$vtype	*vtype;
	_jc_javax_print_event_PrintJobAttributeEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_event_PrintJobAttributeEvent$vtype _jc_javax_print_event_PrintJobAttributeEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_event_PrintJobAttributeEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_event_PrintJobAttributeEvent$class_object;

#endif	/* _JC_javax_print_event_PrintJobAttributeEvent_H_ */

==> jc-1.4.6.tar.gz: javax/print/event/PrintJobAttributeEvent.h <==
// public class javax.print.event.PrintJobAttributeEvent

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 4c95768fb6372ef3 javax_print_event_PrintEvent
// @dep_class a903e261b783b714 javax_print_event_PrintJobAttributeEvent

// header file dependencies
// @dep_header javax_print_event_PrintEvent

#include "javax/print/event/PrintEvent.h"

#ifndef _JC_javax_print_event_PrintJobAttributeEvent_H_
#define _JC_javax_print_event_PrintJobAttributeEvent_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_print_DocPrintJob$object;
struct _jc_javax_print_attribute_PrintJobAttributeSet$object;

// Typedefs
typedef struct _jc_javax_print_event_PrintJobAttributeEvent$sub_refs	_jc_javax_print_event_PrintJobAttributeEvent$sub_refs;
typedef struct _jc_javax_print_event_PrintJobAttributeEvent$sub_nonrefs	_jc_javax_print_event_PrintJobAttributeEvent$sub_nonrefs;
typedef struct _jc_javax_print_event_PrintJobAttributeEvent$refs	_jc_javax_print_event_PrintJobAttributeEvent$refs;
typedef struct _jc_javax_print_event_PrintJobAttributeEvent$nonrefs	_jc_javax_print_event_PrintJobAttributeEvent$nonrefs;
typedef struct _jc_javax_print_event_PrintJobAttributeEvent$object	_jc_javax_print_event_PrintJobAttributeEvent$object;

typedef struct _jc_javax_print_event_PrintJobAttributeEvent$fields_struct	_jc_javax_print_event_PrintJobAttributeEvent$fields_struct;
typedef const struct _jc_javax_print_event_PrintJobAttributeEvent$vmethods	_jc_javax_print_event_PrintJobAttributeEvent$vmethods;
typedef const struct _jc_javax_print_event_PrintJobAttributeEvent$vtable	_jc_javax_print_event_PrintJobAttributeEvent$vtable;
typedef const struct _jc_javax_print_event_PrintJobAttributeEvent$vtype	_jc_javax_print_event_PrintJobAttributeEvent$vtype;

// Class fields structure
struct _jc_javax_print_event_PrintJobAttributeEvent$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_print_event_PrintJobAttributeEvent$fields_struct _jc_javax_print_event_PrintJobAttributeEvent$class_fields;

// Constructors
extern void _jc_javax_print_event_PrintJobAttributeEvent$method$_init$250893578e891781(_jc_env *, struct _jc_javax_print_event_PrintJobAttributeEvent$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_javax_print_event_PrintJobAttributeEvent$method$getAttributes$c572024cf02dfe99(_jc_env *, struct _jc_javax_print_event_PrintJobAttributeEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_print_event_PrintJobAttributeEvent$method$getPrintJob$f4a934baad9b84c8(_jc_env *, struct _jc_javax_print_event_PrintJobAttributeEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_event_PrintJobAttributeEvent$method_info$getAttributes$c572024cf02dfe99;
extern _jc_method _jc_javax_print_event_PrintJobAttributeEvent$method_info$getPrintJob$f4a934baad9b84c8;

// Virtual methods structure
struct _jc_javax_print_event_PrintJobAttributeEvent$vmethods {
	struct _jc_object	*(*getAttributes$c572024cf02dfe99)(_jc_env *, struct _jc_javax_print_event_PrintJobAttributeEvent$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getPrintJob$f4a934baad9b84c8)(_jc_env *, struct _jc_javax_print_event_PrintJobAttributeEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_event_PrintJobAttributeEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_javax_print_event_PrintEvent$vmethods	javax_print_event_PrintEvent;
	_jc_javax_print_event_PrintJobAttributeEvent$vmethods	javax_print_event_PrintJobAttributeEvent;
};

// Vtype
struct _jc_javax_print_event_PrintJobAttributeEvent$vtype {
	_jc_type			type;
	_jc_javax_print_event_PrintJobAttributeEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_event_PrintJobAttributeEvent$sub_refs {
	struct _jc_object	*attributes;
};

// Reference instance fields (object)
struct _jc_javax_print_event_PrintJobAttributeEvent$refs {
    _jc_javax_print_event_PrintJobAttributeEvent$sub_refs	javax_print_event_PrintJobAttributeEvent;
    _jc_javax_print_event_PrintEvent$sub_refs	javax_print_event_PrintEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_event_PrintJobAttributeEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_event_PrintJobAttributeEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_javax_print_event_PrintEvent$sub_nonrefs	javax_print_event_PrintEvent;
    _jc_javax_print_event_PrintJobAttributeEvent$sub_nonrefs	javax_print_event_PrintJobAttributeEvent;
};

// Object instance structure
struct _jc_javax_print_event_PrintJobAttributeEvent$object {
	_jc_javax_print_event_PrintJobAttributeEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_event_PrintJobAttributeEvent$vtype	*vtype;
	_jc_javax_print_event_PrintJobAttributeEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_event_PrintJobAttributeEvent$vtype _jc_javax_print_event_PrintJobAttributeEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_event_PrintJobAttributeEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_event_PrintJobAttributeEvent$class_object;

#endif	/* _JC_javax_print_event_PrintJobAttributeEvent_H_ */
